@@ -106,11 +106,8 @@ class EnviarPedido(Enviar):
 
     def processar_resposta(self, resposta):
         retorno = json.loads(resposta.content)
-        if resposta.status_code == 401:
-            reenviar = retorno["message"] == "expired_token"
-            return {"content": retorno["message"], "status": 401 if reenviar else 400, "reenviar": reenviar}
-        if resposta.status_code == 400:
-            reenviar = retorno["error"] == "invalid_access_token"
+        if resposta.status_code in (400, 401):
+            reenviar = retorno["message"] in ["expired_token", "invalid_token"] or retorno["error"] == "invalid_access_token"
             return {"content": retorno["message"], "status": 401 if reenviar else 400, "reenviar": reenviar}
         if resposta.status_code in (201, 200):
             return {"content": {"url": retorno["init_point"]}, "status": 200, "reenviar": False, "identificador": retorno["id"]}
